==> vmaid-1.8.20.tar.gz: vmaid-1.8.20/src/toolbar.c <==
/*
    Video maid
    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "toolbar.h"
#include "command.h"


/******************************************************************************
*                                                                             *
* ja:ツールバー関数群                                                         *
*                                                                             *
******************************************************************************/
/* XPM */
static gchar *tb_new_xpm[] = {
"16 16 4 1",
"   c None",
".  c #000000",
"+  c #FF0000",
"@  c #FFFFFF",
"          +     ",
" ......+..+..+  ",
" .@@@@@@+@+@+   ",
" .@@@@@@@+++.   ",
" .@@@@+++++++++ ",
" .@@@@@@@+++.   ",
" .@@@@@@+@+@+   ",
" .@@@@@+@@+@.+  ",
" .@@@@@@@@+@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" ............   ",
"                "};


/* XPM */
static gchar *tb_open_xpm[] = {
"16 16 5 1",
"   c None",
".  c #000000",
"=  c #808080",
">  c #FFFF00",
"!  c #FFFFFF",
"  ......        ",
" .!>!>!>.       ",
".!>!>!>!>.......",
".>!>!>!>!>!>!>!.",
".!============>.",
".>=!!!!!!!!!!=!.",
".!=!!!!!!.......",
".>=!!!!!.>!>!>!.",
"........>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
"................"};


/* XPM */
static gchar *tb_save_xpm[] = {
"16 16 5 1",
"  c None",
". c #000000",
"+ c #808000",
"@ c #808080",
"# c #CCCCCC",
"                ",
" .............. ",
" .@@####@@##@@. ",
" .@@####@@##@@. ",
" .@@####@@##@@. ",
" .@@########@@. ",
" .@@@@@@@@@@@@. ",
" .@..........@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .............. ",
"                "};


static gchar *tb_prop_xpm[] = {
"16 16 4 1",
"  c None",
". c #000000",
"+ c #808080",
"@ c #FFFFFF",
"                ",
"  ............  ",
"  .@@@@@@@@@@.  ",
"  .@+++@@@@@@.  ",
"  .@@@@@@@@@@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@@@@@++++@.  ",
"  .@@@@@@@@@@.  ",
"  ............  ",
"                "};


/* XPM */
static gchar *tb_preview_xpm[] = {
"16 16 5 1",
"   c None",
".  c #000000",
"*  c #C0C0C0",
",  c #0000FF",
"!  c #FFFFFF",
"      ......... ",
"      .!!!!!!!. ",
"      .!!!!!!!. ",
"      .!!!!!!!. ",
"      .!!!!!!!. ",
"      .!!!!!!!. ",
"     ...!!!!!!. ",
"    . .!.!!!!!. ",
"   .  .**.!!!!. ",
"   .  .!*.!!!!. ",
"   .  ......... ",
"   ,.   .       ",
"  ,,,...        ",
" ,,,            ",
",,,             ",
" ,              "};


/* XPM */
static gchar *tb_cut_xpm[] = {
"16 16 5 1",
"   c None",
".  c #000000",
"-  c #FF0000",
",  c #0000FF",
"!  c #FFFFFF",
"                ",
"....         ,, ",
"!!!.        ,  ,",
"......,,    ,  ,",
".!!!!.,,,    ,, ",
".!!!!.  ,,,,,   ",
".!!!!.,,,, ,,   ",
".!!,,,,,    ,,, ",
".,,,,,     ,   ,",
".!!!!.     ,   ,",
"......      ,,, ",
"-   -           ",
"--  --          ",
" ------         ",
"    --          ",
"    -           "};


/* XPM */
static gchar *tb_copy_xpm[] = {
"16 16 4 1",
"   c None",
".  c #000000",
"-  c #FF0000",
"!  c #FFFFFF",
"    .........   ",
"    .!!!!!!!.   ",
"    .!!!!!!!.   ",
"    .!!.........",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"-   .!!.!!!!!!!.",
"-   .!!.!!!!!!!.",
"-   ....!!!!!!!.",
"-  -   .!!!!!!!.",
"-- --  .!!!!!!!.",
" ----- .........",
"   --           ",
"   -            "};


/* XPM */
static gchar *tb_paste_xpm[] = {
"16 16 5 1",
"   c None",
".  c #000000",
"*  c #C0C0C0",
"=  c #808080",
"!  c #FFFFFF",
"                ",
"     .........  ",
"     .!!!!!!!.  ",
"     .!!!!!!!.  ",
"  ....!!!!!!!.  ",
"  .!!=!!!!!!!.  ",
"  .!!=!!!!!!!.  ",
"  .!!=====!!!.  ",
"  .!!!*!!=!!!.  ",
"  .!!!!*!=!!!.  ",
"  .!!!!!*=!!!.  ",
"  .!!!!!!=....  ",
"  .!!!!!!!.     ",
"  .!!!!!!!.     ",
"  .........     ",
"                "};


/* XPM */
static gchar *tb_delete_xpm[] = {
"16 16 2 1",
"   c None",
",  c #0000FF",
"                ",
"                ",
"                ",
"             ,, ",
" ,,,,       ,  ,",
"   ,,,,,    ,  ,",
"     ,,,,    ,, ",
"        ,,,,,   ",
"      ,,,, ,,   ",
"   ,,,,,    ,,, ",
" ,,,,,     ,   ,",
"           ,   ,",
"            ,,, ",
"                ",
"                ",
"                "};


/* XPM */
static gchar *tb_undo_xpm[] = {
"16 16 2 1",
"   c None",
"-  c #FF0000",
"                ",
"      ---       ",
"    -------     ",
"   ---   ---    ",
"   --     --    ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --     ------ ",
"  --      ----  ",
"  --       --   ",
"  --            "};


/* XPM */
static gchar *tb_redo_xpm[] = {
"16 16 2 1",
"   c None",
",  c #0000FF",
"            ,,  ",
"   ,,       ,,  ",
"  ,,,,      ,,  ",
" ,,,,,,     ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"    ,,     ,,   ",
"    ,,,   ,,,   ",
"     ,,,,,,,    ",
"       ,,,      ",
"                "};


ToolBar toolbar_items[] = {
/*  0 */ {N_("New"),        tb_new_xpm,     command_new,      NULL, NULL},
/*  1 */ {N_("Open"),       tb_open_xpm,    command_open,     NULL, NULL},
/*  2 */ {N_("Save As"),    tb_save_xpm,    command_save,     NULL, NULL},
/*  3 */ {NULL,             NULL,           NULL,             NULL, NULL},
/*  4 */ {N_("Properties"), tb_prop_xpm,    command_property, NULL, NULL},
/*  5 */ {NULL,             NULL,           NULL,             NULL, NULL},
/*  6 */ {N_("Preview"),    tb_preview_xpm, NULL,             NULL, NULL},
/*  7 */ {NULL,             NULL,           NULL,             NULL, NULL},
/*  8 */ {N_("Cut"),        tb_cut_xpm,     command_cut,      NULL, NULL},
/*  9 */ {N_("Copy"),       tb_copy_xpm,    command_copy,     NULL, NULL},
/* 10 */ {N_("Paste"),      tb_paste_xpm,   command_paste,    NULL, NULL},
/* 11 */ {N_("delete"),     tb_delete_xpm,  command_delete,   NULL, NULL},
/* 12 */ {NULL,             NULL,           NULL,             NULL, NULL},
/* 13 */ {N_("Undo"),       tb_undo_xpm,    command_undo,     NULL, NULL},
/* 14 */ {N_("Redo"),       tb_redo_xpm,    command_redo,     NULL, NULL},
/*    */ {(gpointer)-1,     NULL,           NULL,             NULL, NULL}};

==> vmaid-1.9.0.tar.gz: vmaid-1.9.0/src/toolbar.c <==
/*
    Video maid
    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "toolbar.h"
#include "command.h"


/******************************************************************************
*                                                                             *
* ja:ツールバー関数群                                                         *
*                                                                             *
******************************************************************************/
/* XPM */
static const gchar *tb_new_xpm[] = {
"16 16 4 1",
"   c None",
".  c #000000",
"+  c #FF0000",
"@  c #FFFFFF",
"          +     ",
" ......+..+..+  ",
" .@@@@@@+@+@+   ",
" .@@@@@@@+++.   ",
" .@@@@+++++++++ ",
" .@@@@@@@+++.   ",
" .@@@@@@+@+@+   ",
" .@@@@@+@@+@.+  ",
" .@@@@@@@@+@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" .@@@@@@@@@@.   ",
" ............   ",
"                "};


/* XPM */
static const gchar *tb_open_xpm[] = {
"16 16 5 1",
"   c None",
".  c #000000",
"=  c #808080",
">  c #FFFF00",
"!  c #FFFFFF",
"  ......        ",
" .!>!>!>.       ",
".!>!>!>!>.......",
".>!>!>!>!>!>!>!.",
".!============>.",
".>=!!!!!!!!!!=!.",
".!=!!!!!!.......",
".>=!!!!!.>!>!>!.",
"........>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
".>!>!>!>!>!>!>!.",
".!>!>!>!>!>!>!>.",
"................"};


/* XPM */
static const gchar *tb_save_xpm[] = {
"16 16 5 1",
"  c None",
". c #000000",
"+ c #808000",
"@ c #808080",
"# c #CCCCCC",
"                ",
" .............. ",
" .@@####@@##@@. ",
" .@@####@@##@@. ",
" .@@####@@##@@. ",
" .@@########@@. ",
" .@@@@@@@@@@@@. ",
" .@..........@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .@.++++++++.@. ",
" .............. ",
"                "};


static const gchar *tb_prop_xpm[] = {
"16 16 4 1",
"  c None",
". c #000000",
"+ c #808080",
"@ c #FFFFFF",
"                ",
"  ............  ",
"  .@@@@@@@@@@.  ",
"  .@+++@@@@@@.  ",
"  .@@@@@@@@@@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@++++++++@.  ",
"  .@@@@@@@@@@.  ",
"  .@@@@@++++@.  ",
"  .@@@@@@@@@@.  ",
"  ............  ",
"                "};


/* XPM */
static const gchar *tb_preview_xpm[] = {
"16 16 5 1",
"   c None",
".  c #000000",
"*  c #C0C0C0",
",  c #0000FF",
"!  c #FFFFFF",
"      ......... ",
"      .!!!!!!!. ",
"      .!!!!!!!. ",
"      .!!!!!!!. ",
"      .!!!!!!!. ",
"      .!!!!!!!. ",
"     ...!!!!!!. ",
"    . .!.!!!!!. ",
"   .  .**.!!!!. ",
"   .  .!*.!!!!. ",
"   .  ......... ",
"   ,.   .       ",
"  ,,,...        ",
" ,,,            ",
",,,             ",
" ,              "};


/* XPM */
static const gchar *tb_cut_xpm[] = {
"16 16 5 1",
"   c None",
".  c #000000",
"-  c #FF0000",
",  c #0000FF",
"!  c #FFFFFF",
"                ",
"....         ,, ",
"!!!.        ,  ,",
"......,,    ,  ,",
".!!!!.,,,    ,, ",
".!!!!.  ,,,,,   ",
".!!!!.,,,, ,,   ",
".!!,,,,,    ,,, ",
".,,,,,     ,   ,",
".!!!!.     ,   ,",
"......      ,,, ",
"-   -           ",
"--  --          ",
" ------         ",
"    --          ",
"    -           "};


/* XPM */
static const gchar *tb_copy_xpm[] = {
"16 16 4 1",
"   c None",
".  c #000000",
"-  c #FF0000",
"!  c #FFFFFF",
"    .........   ",
"    .!!!!!!!.   ",
"    .!!!!!!!.   ",
"    .!!.........",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"    .!!.!!!!!!!.",
"-   .!!.!!!!!!!.",
"-   .!!.!!!!!!!.",
"-   ....!!!!!!!.",
"-  -   .!!!!!!!.",
"-- --  .!!!!!!!.",
" ----- .........",
"   --           ",
"   -            "};


/* XPM */
static const gchar *tb_paste_xpm[] = {
"16 16 5 1",
"   c None",
".  c #000000",
"*  c #C0C0C0",
"=  c #808080",
"!  c #FFFFFF",
"                ",
"     .........  ",
"     .!!!!!!!.  ",
"     .!!!!!!!.  ",
"  ....!!!!!!!.  ",
"  .!!=!!!!!!!.  ",
"  .!!=!!!!!!!.  ",
"  .!!=====!!!.  ",
"  .!!!*!!=!!!.  ",
"  .!!!!*!=!!!.  ",
"  .!!!!!*=!!!.  ",
"  .!!!!!!=....  ",
"  .!!!!!!!.     ",
"  .!!!!!!!.     ",
"  .........     ",
"                "};


/* XPM */
static const gchar *tb_delete_xpm[] = {
"16 16 2 1",
"   c None",
",  c #0000FF",
"                ",
"                ",
"                ",
"             ,, ",
" ,,,,       ,  ,",
"   ,,,,,    ,  ,",
"     ,,,,    ,, ",
"        ,,,,,   ",
"      ,,,, ,,   ",
"   ,,,,,    ,,, ",
" ,,,,,     ,   ,",
"           ,   ,",
"            ,,, ",
"                ",
"                ",
"                "};


/* XPM */
static const gchar *tb_undo_xpm[] = {
"16 16 2 1",
"   c None",
"-  c #FF0000",
"                ",
"      ---       ",
"    -------     ",
"   ---   ---    ",
"   --     --    ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --       --   ",
"  --     ------ ",
"  --      ----  ",
"  --       --   ",
"  --            "};


/* XPM */
static const gchar *tb_redo_xpm[] = {
"16 16 2 1",
"   c None",
",  c #0000FF",
"            ,,  ",
"   ,,       ,,  ",
"  ,,,,      ,,  ",
" ,,,,,,     ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"   ,,       ,,  ",
"    ,,     ,,   ",
"    ,,,   ,,,   ",
"     ,,,,,,,    ",
"       ,,,      ",
"                "};


MiscCreateToolbarEntry toolbar_entries[] = {
{"new",        N_("New"),        tb_new_xpm,     command_new,      NULL, NULL},
{"open",       N_("Open"),       tb_open_xpm,    command_open,     NULL, NULL},
{"saveas",     N_("Save As"),    tb_save_xpm,    command_save,     NULL, NULL},
{"sep1",       NULL,             NULL,           NULL,             NULL, NULL},
{"properties", N_("Properties"), tb_prop_xpm,    command_property, NULL, NULL},
{"sep2",       NULL,             NULL,           NULL,             NULL, NULL},
{"preview",    N_("Preview"),    tb_preview_xpm, NULL,             NULL, NULL},
{"sep3",       NULL,             NULL,           NULL,             NULL, NULL},
{"cut",        N_("Cut"),        tb_cut_xpm,     command_cut,      NULL, NULL},
{"copy",       N_("Copy"),       tb_copy_xpm,    command_copy,     NULL, NULL},
{"paste",      N_("Paste"),      tb_paste_xpm,   command_paste,    NULL, NULL},
{"delete",     N_("delete"),     tb_delete_xpm,  command_delete,   NULL, NULL},
{"sep4",       NULL,             NULL,           NULL,             NULL, NULL},
{"undo",       N_("Undo"),       tb_undo_xpm,    command_undo,     NULL, NULL},
{"redo",       N_("Redo"),       tb_redo_xpm,    command_redo,     NULL, NULL},
{NULL,         NULL,             NULL,           NULL,             NULL, NULL}};
